@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2020 Joël Krähemann
+ * Copyright (C) 2005-2021 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -653,79 +653,6 @@ ags_audiorec_map_recall(AgsMachine *machine)
 				       (AGS_FX_FACTORY_ADD | AGS_FX_FACTORY_INPUT),
 				       0);
 
-  recall = start_recall;
-
-  while((recall = ags_recall_template_find_type(recall, AGS_TYPE_FX_PLAYBACK_AUDIO)) != NULL){
-    AgsPort *port;
-
-    GValue value = G_VALUE_INIT;
-    
-    /* loop */
-    port = NULL;
-    
-    g_object_get(recall->data,
-		 "loop", &port,
-		 NULL);
-
-    g_value_init(&value,
-		 G_TYPE_BOOLEAN);
-
-    g_value_set_boolean(&value,
-			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(navigation->loop)));
-
-    ags_port_safe_write(port,
-			&value);
-
-    if(port != NULL){
-      g_object_unref(port);
-    }
-    
-    /* loop start */
-    port = NULL;
-    
-    g_object_get(recall->data,
-		 "loop-start", &port,
-		 NULL);
-
-    g_value_unset(&value);
-    g_value_init(&value,
-		 G_TYPE_UINT64);
-
-    g_value_set_uint64(&value,
-		       16 * gtk_spin_button_get_value_as_int(navigation->loop_left_tact));
-
-    ags_port_safe_write(port,
-			&value);
-
-    if(port != NULL){
-      g_object_unref(port);
-    }
-    
-    /* loop end */
-    port = NULL;
-    
-    g_object_get(recall->data,
-		 "loop-end", &port,
-		 NULL);
-
-    g_value_unset(&value);
-    g_value_init(&value,
-		 G_TYPE_UINT64);
-
-    g_value_set_uint64(&value,
-		       16 * gtk_spin_button_get_value_as_int(navigation->loop_right_tact));
-
-    ags_port_safe_write(port,
-			&value);
-
-    if(port != NULL){
-      g_object_unref(port);
-    }
-
-    /* iterate */
-    recall = recall->next;
-  }
-
   g_list_free_full(start_recall,
 		   (GDestroyNotify) g_object_unref);
 
