@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2020 Joël Krähemann
+ * Copyright (C) 2005-2021 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -100,6 +100,12 @@ ags_sfz_synth_util_copy_s8(gint8 *buffer,
   guint i0, i1, i2;
   gboolean success;
   gboolean pong_copy;
+
+  if(buffer == NULL ||
+     sfz_sample == NULL ||
+     !AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return;
+  }
   
   source_frame_count = 0;
 
@@ -367,6 +373,12 @@ ags_sfz_synth_util_copy_s16(gint16 *buffer,
   gboolean success;
   gboolean pong_copy;
 
+  if(buffer == NULL ||
+     sfz_sample == NULL ||
+     !AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return;
+  }
+
   source_frame_count = 0;
 
   source_samplerate = AGS_SOUNDCARD_DEFAULT_SAMPLERATE;
@@ -633,6 +645,12 @@ ags_sfz_synth_util_copy_s24(gint32 *buffer,
   gboolean success;
   gboolean pong_copy;
 
+  if(buffer == NULL ||
+     sfz_sample == NULL ||
+     !AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return;
+  }
+
   source_frame_count = 0;
 
   source_samplerate = AGS_SOUNDCARD_DEFAULT_SAMPLERATE;
@@ -898,6 +916,12 @@ ags_sfz_synth_util_copy_s32(gint32 *buffer,
   guint i0, i1, i2;
   gboolean success;
   gboolean pong_copy;
+
+  if(buffer == NULL ||
+     sfz_sample == NULL ||
+     !AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return;
+  }
   
   source_frame_count = 0;
 
@@ -1165,6 +1189,12 @@ ags_sfz_synth_util_copy_s64(gint64 *buffer,
   gboolean success;
   gboolean pong_copy;
 
+  if(buffer == NULL ||
+     sfz_sample == NULL ||
+     !AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return;
+  }
+
   source_frame_count = 0;
 
   source_samplerate = AGS_SOUNDCARD_DEFAULT_SAMPLERATE;
@@ -1431,6 +1461,12 @@ ags_sfz_synth_util_copy_float(gfloat *buffer,
   gboolean success;
   gboolean pong_copy;
 
+  if(buffer == NULL ||
+     sfz_sample == NULL ||
+     !AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return;
+  }
+
   source_frame_count = 0;
 
   source_samplerate = AGS_SOUNDCARD_DEFAULT_SAMPLERATE;
@@ -1696,6 +1732,12 @@ ags_sfz_synth_util_copy_double(gdouble *buffer,
   guint i0, i1, i2;
   gboolean success;
   gboolean pong_copy;
+
+  if(buffer == NULL ||
+     sfz_sample == NULL ||
+     !AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return;
+  }
     
   source_frame_count = 0;
 
@@ -1963,6 +2005,12 @@ ags_sfz_synth_util_copy_complex(AgsComplex *buffer,
   gboolean success;
   gboolean pong_copy;
 
+  if(buffer == NULL ||
+     sfz_sample == NULL ||
+     !AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return;
+  }
+
   source_frame_count = 0;
 
   source_samplerate = AGS_SOUNDCARD_DEFAULT_SAMPLERATE;
@@ -2209,6 +2257,12 @@ ags_sfz_synth_util_copy(void *buffer,
 			guint loop_mode,
 			gint loop_start, gint loop_end)
 {
+  if(buffer == NULL ||
+     sfz_sample == NULL ||
+     !AGS_IS_SFZ_SAMPLE(sfz_sample)){
+    return;
+  }
+
   switch(audio_buffer_util_format){
   case AGS_AUDIO_BUFFER_UTIL_S8:
   {
